@@ -202,7 +202,7 @@ class MultiplayerTurnCheckWorker(appContext: Context, workerParams: WorkerParame
                     gameIds[count] = gamePreview.gameId
                     gameNames[count] = gameFile.name()
                     count++
-                } catch (ex: Throwable) {
+                } catch (_: Throwable) {
                     //only loadGamePreviewFromFile can throw an exception
                     //nothing will be added to the arrays if it fails
                     //just skip one file
