@@ -34,7 +34,7 @@ import org.junit.runner.RunWith
 class CapitalConnectionsFinderTests {
 
     private var gameInfo = GameInfo()
-    private val testCivilizationNames = arrayListOf("America", "Germany", "Greece")
+    private val testCivilizationNames = arrayListOf("America", "Germany", "Greece","Hanoi", "Genoa")
     private var rules = Ruleset()
 
     private fun ourCiv() = gameInfo.civilizations.first()
@@ -71,16 +71,17 @@ class CapitalConnectionsFinderTests {
     }
 
     private fun createCity(civInfo: Civilization, position: Vector2, name: String, capital: Boolean = false, hasHarbor: Boolean = false): City {
-        return City().apply {
+        val city =  City().apply {
             location = position
-            if (capital)
-                cityConstructions.builtBuildings.add(rules.buildings.values.first { it.hasUnique(UniqueType.IndicatesCapital) }.name)
-            if (hasHarbor)
-                cityConstructions.builtBuildings.add(rules.buildings.values.first { it.hasUnique(UniqueType.ConnectTradeRoutes) }.name)
             this.name = name
             setTransients(civInfo)
             gameInfo.tileMap[location].setOwningCity(this)
         }
+        if (capital)
+            city.cityConstructions.addBuilding(rules.buildings.values.first { it.hasUnique(UniqueType.IndicatesCapital) }.name)
+        if (hasHarbor)
+            city.cityConstructions.addBuilding(rules.buildings.values.first { it.hasUnique(UniqueType.ConnectTradeRoutes) }.name)
+        return city
     }
 
     private fun meetCivAndSetBorders(name: String, areBordersOpen: Boolean) {
@@ -195,16 +196,16 @@ class CapitalConnectionsFinderTests {
             createCity(ourCiv(), Vector2(0f, -4f), "Not connected"),
             createCity(ourCiv(), Vector2(0f, 4f), "Connected"))
 
-        val openCiv = gameInfo.getCivilization("Germany")
-        openCiv.nation.cityStateType = "Cultured"
+        val openCiv = gameInfo.getCivilization("Hanoi")
+//         openCiv.nation.cityStateType = "Cultured"
         openCiv.cities = listOf( createCity(openCiv, Vector2(0f, 2f), "Berlin", true))
-        ourCiv().diplomacy["Germany"] = DiplomacyManager(ourCiv(), "Germany")
+        ourCiv().diplomacy["Hanoi"] = DiplomacyManager(ourCiv(), "Hanoi")
             .apply { diplomaticStatus = DiplomaticStatus.Peace }
 
-        val closedCiv = gameInfo.getCivilization("Greece")
+        val closedCiv = gameInfo.getCivilization("Genoa")
         closedCiv.nation.cityStateType = "Cultured"
         closedCiv.cities = listOf( createCity(closedCiv, Vector2(0f, -2f), "Athens", true))
-        ourCiv().diplomacy["Greece"] = DiplomacyManager(ourCiv(), "Greece")
+        ourCiv().diplomacy["Genoa"] = DiplomacyManager(ourCiv(), "Genoa")
             .apply { diplomaticStatus = DiplomaticStatus.War }
 
 
