@@ -2,7 +2,7 @@ package com.unciv.testing
 
 import com.unciv.models.TutorialTrigger
 import com.unciv.models.ruleset.Tutorial
-import com.unciv.ui.tutorials.TutorialController
+import com.unciv.ui.screens.basescreen.TutorialController
 import org.junit.Assert.fail
 import org.junit.Test
 import org.junit.runner.RunWith
